@@ -1,16 +1,11 @@
 package AnyEvent::Impl::CoroEV;
 
-use base AnyEvent::Impl::EV;
+use base qw(AnyEvent::Impl::Coro AnyEvent::Impl::EV);
 
 use strict;
 no warnings;
 
 use Coro::EV ();
-use Coro::Signal ();
-
-sub condvar {
-   new Coro::Signal
-}
 
 1
 
